#!/usr/bin/env python3

import markdown
import pathlib
import sys
import re
import glob
import os

def print_usage():
    print("\nusage: python feed.py ROOT\n")
    print("\n")
    print("\t\ROOT\tbase folder")

# check args for at most one file paths
if len(sys.argv) > 2:
    print_usage()
    sys.exit(1)

base_folder = sys.argv[1] if len(sys.argv) == 2 else os.getcwd()
print(base_folder)

def get_paths() -> [str]:
    return [x for x in glob.glob(f"{base_folder}/*.md")]

def get_text(path):
    with open(path) as f:
        return f.read()

#def to_html(md : str) -> str:
#    return markdown.markdown(md, extensions=["fenced_code"])

def get_title(md):
    m = re.compile(r"^# (.+)\n").match(md)
    if m is not None:
        return m.groups(1)[0]

    # truncated first line of file for auto-title
    return md.splitlines()[0][0:30]

def get_entry(path):
    return get_title(get_text(path))

def get_entries() -> [str]:
    entries = [get_entry(p) for p in get_paths()]
    return "\n\n".join(entries)

def get_header() -> str:
    return """<?xml version="1.0" encoding="utf-8" ?>
<rss xmlns:atom="http://www.w3.org/2005/Atom" version="2.0">
<channel>
    <title></title>
    <link>https://ktyl.dev/garden</link>
    <description></description>
    <atom:link href="https://ktyl.dev/garden/feed.xml" rel="self" type="application/rss+xml"/>
"""

def get_footer() -> str:
    return "\n</channel></rss>"

print(get_header())
print(get_entries())
print(get_footer())
